%define _name libgda

%def_with mysql
%def_with postgres
%def_with odbc
%def_with mdb
%def_with interbase
%def_with ldap
%def_without oracle
%def_without sqlite
%def_without tds
%def_without sybase

Name: libgda2
Version: 0.10.0
Release: alt2

Summary: Library for writing gnome database programs
Group: System/Libraries
License: LGPL
Url: ftp://ftp.gnome.org

Source: %_name-%version.tar.bz2

%if_with postgres
%define postgresql_ver 7.3.1-alt5
BuildPreReq: libpq3-devel >= %postgresql_ver
BuildPreReq: postgresql-devel >= %postgresql_ver
%endif

%if_with mysql
BuildPreReq: libMySQL-devel
%endif

%if_with odbc
BuildPreReq: libunixODBC-devel
%endif

%if_with mdb
%define mdbtools_ver 0.5
BuildPreReq: libmdbtools-devel >= %mdbtools_ver
%endif

%if_with interbase
BuildPreReq: interbase
%endif

%if_with ldap
%define ldap_ver 2.0.27-alt3
BuildPreReq: libldap-devel >= %ldap_ver
%endif

# Automatically added by buildreq on Sun Feb 09 2003
#BuildRequires: FirebirdCS docbook-dtds docbook-style-dsssl flex gcc-c++ glib2-devel glibc-devel-static gtk-doc libMySQL-devel libdb2-devel libldap-devel libmdbtools-devel libncurses-devel libpopt-devel libpq3-devel libreadline-devel libunixODBC-devel libxml2-devel libxslt-devel openjade pkgconfig postgresql-devel scrollkeeper sgml-common zlib-devel
BuildRequires: docbook-dtds docbook-style-dsssl flex gcc-c++ glib2-devel glibc-devel-static
BuildRequires: gtk-doc libldap-devel libncurses-devel libpopt-devel libreadline-devel
BuildRequires: libxml2-devel libxslt-devel openjade pkgconfig scrollkeeper sgml-common zlib-devel

%description
GNU Data Access is an attempt to provide uniform access to
different kinds of data sources (databases, information
servers, mail spools, etc).
It is a complete architecture that provides all you need to
access your data.

libgda was part of the GNOME-DB project
(http://www.gnome.org/projects/gnome-db), but has been
separated from it to allow non-GNOME applications to be
developed based on it.

%package providers
Summary: GDA service providers for %name
Group: System/Libraries
%if_with mysql
Requires: %name-mysql = %version-%release
%endif
%if_with postgres
Requires: %name-postgresql = %version-%release
%endif
%if_with odbc
Requires: %name-odbc = %version-%release
%endif
%if_with mdb
Requires: %name-mdb = %version-%release
%endif
%if_with interbase
Requires: %name-interbase = %version-%release
%endif
%if_with ldap
Requires: %name-ldap = %version-%release
%endif

%description providers
This package includes:
%if_with ldap
GDA LDAP provider.
%endif
%if_with mysql
GDA MySQL provider.
%endif
%if_with postgres
GDA PostgreSQL provider.
%endif
%if_with odbc
GDA ODBC provider.
%endif
%if_with interbase
GDA Interbase provider.
%endif
%if_with ldap
GDA LDAP provider.
%endif

%package mysql
Summary: GDA MySQL Provider
Group: System/Libraries
Requires: %name = %version-%release

%description mysql
This package includes the GDA MySQL provider.

%package postgresql
Summary: GDA PostgreSQL Provider
Group: System/Libraries
Requires: %name = %version-%release
Requires: libpq3 >= %postgresql_ver

%description postgresql
This package includes the GDA PostgreSQL provider.

%package odbc
Summary: GDA ODBC Provider
Group: System/Libraries
Requires: %name = %version-%release

%description odbc
This package includes the GDA ODBC provider.

%package mdb
Summary: GDA MS Access Provider
Group: System/Libraries
Requires: %name = %version-%release
Requires: libmdbtools >= %mdbtools_ver

%description mdb
This package includes the GDA MS Access provider.

%package interbase
Summary: GDA Interbase Provider
Group: System/Libraries
Requires: %name = %version-%release
Requires: interbase

%description interbase
This package includes the GDA Intebase provider

%package ldap
Summary: GDA LDAP Provider
Group: System/Libraries
Requires: %name = %version-%release

%description ldap
This package includes the GDA LDAP provider

%package devel
Summary: Development libraries and header files for libgda
Group: Development/C
Requires: %name = %version-%release
Requires: %name-providers = %version-%release
%if_with mysql
Requires: libMySQL-devel
%endif
%if_with postgres
Requires: postgresql-devel >= %postgresql_ver
%endif
%if_with odbc
Requires: libunixODBC-devel
%endif
%if_with interbase
Requires: interbase
%endif

%description devel
This package contains the header files and libraries needed to write
or compile programs that use libgda.

%package devel-static
Summary: Static libraries for libgda
Group: Development/C
Requires: %name-devel = %version-%release

%description devel-static
This package contains the static version of %_name libraries.

%prep
%setup -q -n %_name-%version

%build
%configure --program-suffix="-2" \
%if_with mysql
	--with-mysql \
%endif
%if_with postgres
	--with-postgres=/usr \
%endif
%if_with odbc
	--with-odbc \
%endif
%if_with mdb
	--with-mdb \
%endif
%if_with oracle
	--with-oracle \
%endif
%if_with interbase
	--with-interbase=%prefix \
%endif
%if_with tds
	--with-tds \
%else
	--with-tds=no \
%endif
%if_with sybase
	--with-sybase \
%else
	--with-sybase=no \
%endif
%if_with sqlite
	--with-sqlite
%endif

%make_build

%install
%make_install DESTDIR=%buildroot \
    LIBRARY_PATH=%buildroot%libdir install

%find_lang %_name-2

%post
%post_ldconfig
%update_scrollkeeper

%postun
%postun_ldconfig
%clean_scrollkeeper

%files -f %_name-2.lang
%_bindir/*
%_libdir/*.so.*
%_libdir/%_name/*/*default.so
#%_datadir/idl/*
%_datadir/%_name
%_datadir/omf/*
%_mandir/man?/*
%config(noreplace) %_sysconfdir/%_name/config
%doc AUTHORS ChangeLog README NEWS

%files providers

%if_with mysql
%files mysql
%_libdir/%_name/*/*-mysql.so
%endif

%if_with postgres
%files postgresql
%_libdir/%_name/*/*-postgres.so
%endif

%if_with mdb
%files mdb
%_libdir/%_name/*/*-mdb.so
%endif

%if_with odbc
%files odbc
%_libdir/%_name/*/*-odbc.so
%endif

%if_with interbase
%files interbase
%_libdir/%_name/*/*-firebird.so
%endif

%if_with ldap
%files ldap
%_libdir/%_name/*/*-ldap.so
%endif

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/*.la
%_libdir/%_name/*/*.la
%_libdir/pkgconfig/*
%doc %_datadir/gtk-doc/html/*

%files devel-static
%_libdir/*.a
%_libdir/%_name/*/*.a

%changelog
* Sun Feb 09 2003 Yuri N. Sedunov <aris@altlinux.ru> 0.10.0-alt2
- fixed buildreqs (close #2181).

* Tue Jan 28 2003 Yuri N. Sedunov <aris@altlinux.ru> 0.10.0-alt1
- 0.10.0

* Thu Dec 12 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.9.0-alt1
- new version.
- mdb provider.

* Wed Dec 04 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.8.199-alt2
- Removed wrong dependence on postgresql-libs for main package (#1660)

* Mon Oct 28 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.8.199-alt1
- 0.8.199

* Sun Sep 22 2002 Yuri N. Sedunov <aris@altlinux.ru> 0.8.192-alt1
- Adopted for Sisyphus.
- devel-static package.
- providers moved in separate packages.

* Tue Feb 26 2002 Chris Chabot <chabotc@reviewboard.com>
- Added defines and configure flags for all supported DB types

* Mon Feb 25 2002 Chris Chabot <chabotc@reviewboard.com>
- Cleaned up formatting
- Added Requirements
- Added defines for postgres, mysql, odbc support

* Thu Feb 21 2002 Chris Chabot <chabotc@reviewboard.com>
- Initial spec file
